@@ -12,7 +12,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = ();
 our @EXPORT_OK = qw( num2hu );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our %dig;
 
@@ -23,23 +23,34 @@ huszonngy huszont huszonhat huszonht huszonnyolc huszonkilenc harminc
 negyven tven hatvan hetven nyolcvan kilencven );
 
 our @desc = ('',qw(ezer milli millird billi billird trilli trillird 
-	kvadrilli kvadrillird kvintilli kvintillird szextilli 
+	kvadrilli kvadrillird kvintilli kvintillird szextilli szextillird
 	szeptilli szeptillird oktilli oktillird nonilli nonillird
 	decilli decillird));
 
+our @frac = ('',qw( ezred milliomod millirdod billiomod billirdod
+	trilliomod trillirdod kvadrilliomod kvadrillirdod kvintilliomod
+	kvintillirdod szextilliomod szextillirdod szeptilliomod szeptillirdod
+	oktilliomod oktillirdod nonilliomod nonillirdod decilliomod 
+	decillirdod ));
+
 sub num2hu {
 	my $num = $_[0];
 	return $dig{'0'} if ($num =~ m/^[+-]0+$/s);
 	return undef unless defined $num && length $num;
-	croak("Currently the module only works with integers!")
-		if ($num !~ m/^[+-]?\d+$/s);
-	
+	croak("Number is not properly formatted!")
+		if ($num !~ m/^[+-]?\d+(\.\d+)?$/s);
+	my ($int,$frac) = $num =~ m/^[+-]?(\d+)(?:\.(\d+))?$/;
 	croak("The number is too large, the module can't handle it!")
-		if (length($num) > 67);
+		if ($int && length($int) > 66 || $frac && length($frac) > 66);
 	my $plusmin = '';
 	$num =~ s/^([+-])/$plusmin = $1;''/es;
 	$plusmin = ($plusmin eq '-') ? 'mnusz ':'';
-	return $plusmin._int2hu($num);
+	if ($num =~ m/(\d+)\.(\d+)/) {
+		if (_frac2hu($2)) { return $plusmin._int2hu($1).' egsz '._frac2hu($2)
+		} else { return $plusmin._int2hu($1); }
+	} else {
+		return $plusmin._int2hu($num);
+	}
 }
 
 sub _int2hu {
@@ -90,22 +101,33 @@ sub _bigint2hu {
 	}
 	return join('-',@out);
 	
+}
+
+sub _frac2hu {
+	my $num = $_[0];
+	$num =~ s/0+$//;
+	my $place = length($num);
+	$num =~ s/^0+//;
+	return undef if ($num eq '');
+	if ($place < 3) { 
+		$place = ($place == 1) ? 'tized':'szzad';
+		return _int2hu($num).' '.$place;
+	} else {
+		my $rest = '';
+		$rest = _int2hu('1'.('0' x ($place % 3))) if ($place % 3);
+		$place = int( $place / 3 );
+		return _int2hu($num).' '.$rest.$frac[$place];
+	}
+
+
 }
 =head1 NAME
 
 Lingua::HU::Numbers - converts numbers into Hungarian language text form.
 
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
 =head1 SYNOPSIS
 
 
-Perhaps a little code snippet.
-
     use Lingua::HU::Numbers qw/num2hu/;
 
     my $number = "42";
@@ -118,7 +140,7 @@ prints
 
 =head1 DESCRIPTION
 
-Lingua::HU::Numbers is a module converting numbers (like "42") into their 
+Lingua::HU::Numbers is a module converting numbers (like "42") into their
 Hungarian language representation ("negyvenkett").
 
 Currently the only function that can be exported is C<num2hu>.
@@ -132,8 +154,8 @@ Please see the README file for details of Hungarian grammar.
 =item * num2hu
 
 This function is the only available one at the moment.
-It takes a scalar value which currently must be a positive integer smaller
-than 10**66. The return value is a scalar expressing the Hungarian text
+It takes a scalar value which currently must be a real number smaller
+than -+10**66. The return value is a scalar expressing the Hungarian text
 version of the given number.
 
 =cut
@@ -142,12 +164,12 @@ version of the given number.
 
 =head1 LIMITATIONS
 
-The module cannot handle anything but integers smaller than 10**66
+The module cannot handle numbers larger than -+10**66
 at the moment.
 
 =head1 FUTURE PLANS
 
-Real number, exponential notation, num2hu_ordinal, fraction
+Exponential notation, num2hu_ordinal, fraction
 support will be added in the next few releases. Patches welcome.
 
 The module aims to remain similar in structure to L<Lingua::EN::Numbers>,
